@@ -10,6 +10,7 @@ from sympy.core.sympify import SympifyError
 from tqdm import tqdm
 from torchvision.models import efficientnet_b0, EfficientNet_B0_Weights
 import timm
+from .latex_list import lst
 import os
 
 BATCH_SIZE = 16
@@ -17,7 +18,7 @@ CORES = 16
 TOTAL_EPOCHS = 25
 import os
 
-JSON_PATH = os.path.join(os.path.dirname(__file__), 'datasets', 'val.json')
+JSON_PATH = os.path.join(os.path.dirname(__file__), 'empty.json')
 PT_SAVE = 'graphite_test_val.pt'
 
 def collate_fn(batch):
@@ -115,12 +116,8 @@ class TransformerDecoder(nn.Module):
         logits = self.fc(output)
         return logits
 
-with open(JSON_PATH, 'r', encoding='utf-8') as f:
-    raw_data = json.load(f)
-latex_list = [pair['latex'] for pair in raw_data['pairs'] if pair.get('latex') is not None]
-
 tokenizer = LatexTokenizer()
-tokenizer.build_vocab(latex_list)
+tokenizer.build_vocab(lst)
 
 class MathDatasetWithType(MathDataset):
     """
