@@ -8,6 +8,7 @@ warnings.filterwarnings(
 )
 
 import torch
+import os
 import torch.nn as nn
 from torchvision import transforms
 from PIL import Image
@@ -15,6 +16,19 @@ from .create_model import TransformerDecoder, LatexTokenizer  # adjust imports i
 
 import re
 
+import torch
+import requests
+
+MODEL_PATH = os.path.join(os.path.dirname(__file__), "graphite.pt")
+MODEL_URL = "https://huggingface.co/whoisarjun/graphite/resolve/main/graphite.pt"
+
+if not os.path.exists(MODEL_PATH):
+    print("Downloading model...")
+    r = requests.get(MODEL_URL, stream=True)
+    with open(MODEL_PATH, "wb") as f:
+        for chunk in r.iter_content(chunk_size=8192):
+            f.write(chunk)
+
 def clean_latex(raw_latex: str) -> str:
     replacements = {
         'LEFTBRACE': '{',
@@ -57,7 +71,7 @@ def clean_latex(raw_latex: str) -> str:
     return raw_latex
 
 class Graphite:
-    def __init__(self, model_path=os.path.join(os.path.dirname(__file__), 'graphite.pt'), device=None):
+    def __init__(self, model_path=MODEL_PATH, device=None):
         self.device = device or (torch.device('cuda') if torch.cuda.is_available() else torch.device('cpu'))
 
         checkpoint = torch.load(model_path, map_location=self.device)
